==> v3.7.3.zip: yuito-app-android/README.md <==
[![Translate - with Weblate](https://img.shields.io/badge/translate%20with-Weblate-green.svg?style=flat)](https://weblate.tusky.app/) [![test](https://github.com/accelforce/Yuito/workflows/test/badge.svg?branch=master&event=push)](https://github.com/accelforce/Yuito/actions?query=workflow%3Atest+event%3Apush+branch%3Amaster)
# Yuito

<img src="/app/src/blue/ic_launcher-web.png" height="160" />

[<img src="https://play.google.com/intl/en_us/badges/images/generic/en_badge_web_generic.png" alt="Get it on Google Play" height="80" />](https://play.google.com/store/apps/details?id=net.accelf.yuito)

Yuito is fork of [Tusky](https://github.com/tuskyapp/Tusky).

Tusky is a beautiful Android client for [Mastodon](https://github.com/tootsuite/mastodon). Mastodon is an ActivityPub federated social network. That means no single entity controls the whole network, rather, like e-mail, volunteers and organisations operate their own independent servers, users from which can all interact with each other seamlessly.

## Features

- Material Design
- Most Mastodon APIs implemented
- Multi-Account support
- Dark, light and black themes with the possibility to auto-switch based on the time of day
- Drafts - compose toots and save them for later
- Choose between different emoji styles 
- Optimized for all screen sizes
- Completely open-source - no non-free dependencies like Google services

### Support

If you have any bug reports, feature requests or questions please open an issue or send us a toot at [@ars42525@odakyu.app](https://odakyu.app/@ars42525)!

For translating Tusky into your language, visit https://weblate.tusky.app/

### Head of development

This app was developed by [@ars42525@odakyu.app](https://odakyu.app/@ars42525).

==> v4.2.1.zip: yuito-app-android/README.md <==
[![Translate - with Weblate](https://img.shields.io/badge/translate%20with-Weblate-green.svg?style=flat)](https://weblate.tusky.app/) [![test](https://github.com/accelforce/Yuito/workflows/test/badge.svg?branch=master&event=push)](https://github.com/accelforce/Yuito/actions?query=workflow%3Atest+event%3Apush+branch%3Amaster)
# Yuito

<img src="/app/src/blue/ic_launcher-web.png" height="160" />

[<img src="https://play.google.com/intl/en_us/badges/images/generic/en_badge_web_generic.png" alt="Get it on Google Play" height="80" />](https://play.google.com/store/apps/details?id=net.accelf.yuito)

Yuito is fork of [Tusky](https://github.com/tuskyapp/Tusky).

Tusky is a beautiful Android client for [Mastodon](https://github.com/mastodon/mastodon). Mastodon is an ActivityPub federated social network. That means no single entity controls the whole network, rather, like e-mail, volunteers and organisations operate their own independent servers, users from which can all interact with each other seamlessly.

## Features

- Material Design
- Most Mastodon APIs implemented
- Multi-Account support
- Dark, light and black themes with the possibility to auto-switch based on the time of day
- Drafts - compose posts and save them for later
- Choose between different emoji styles 
- Optimized for all screen sizes
- Completely open-source - no non-free dependencies like Google services

### Support

If you have any bug reports, feature requests or questions please open an issue or send us a message at [@ars42525@odakyu.app](https://odakyu.app/@ars42525)!

For translating Tusky into your language, visit https://weblate.tusky.app/

### Head of development

This app was developed by [@ars42525@odakyu.app](https://odakyu.app/@ars42525).
